@@ -56,6 +56,9 @@ class Parser:
     def get_image_from_canvas(self, path: str, local_path: str, element: any=None) -> str:
         return self.scraper.get_image_from_canvas(path=path, local_path=local_path, element=element)
 
+    def switch_to(self, element: any) -> None:
+        self.scraper.switch_to(element=element)
+
     #endregion methods
 
     def get_scraper(self, headless: bool=True, window: dict={}) -> Scraper:
