@@ -235,5 +235,8 @@ class Scraper:
     def get_image_from_canvas(self, path: str, local_path: str, element: any) -> str:
         return self.on_get_image_from_canvas(path=path, local_path=local_path, element=element)
 
+    def switch_to(self, element: any) -> None:
+        return self.on_switch_to(element=element)
+
     def close(self):
         self.on_close()
\ No newline at end of file
