@@ -33,17 +33,22 @@ class Selenium(Scraper):
 
         if len(window_size) == 0:
             options.add_argument('start-maximized')
+            options.add_argument("window-size=1280,800") # new
 
         if headless is True:
             options.add_argument('headless')
 
         LOGGER.setLevel(logging.WARNING)
 
+        options.add_argument('--disable-blink-features=AutomationControlled') # new
+        options.add_argument("user-agent=Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/74.0.3729.169 Safari/537.36") # new
+
+
         if platform.system() == 'Windows':
             self.driver = webdriver.Chrome(executable_path='c:\chromedriver.exe', options=options)
         if platform.system() == 'Linux':
             self.driver = webdriver.Chrome(executable_path='/chromedriver', options=options)
-        
+
         if len(window_size) > 0:
             self.driver.set_window_position(x=0, y=0)
             self.driver.set_window_size(width=window_size[0], height=window_size[1])
